package com.huaching.parking.local.parking_local_general.domain.local.bo;

import com.alibaba.fastjson.JSON;
import com.huaching.parking.local.parking_local_general.domain.local.po.ThsChargingRulesPO;
import com.huaching.parking.local.parking_local_general.service.local.MemberCarHelperService;
import com.huaching.parking.local.parking_local_general.util.local.DateUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Comparator;
import java.util.Date;
import java.util.List;
import java.util.UUID;

/**
 * @program: parking_local_general
 * @description: 计算请求费用BO处理类
 * @author: lidongsheng
 * @createData: 2020-04-22 13:41
 * @updateAuthor: lidongsheng
 * @updateData: 2020-04-22 13:41
 * @updateContent:
 * @Version: 1.0.0

 * @blog: www.b0c0.com
 * ************************************************
 * Copyright @ 李东升 2020. All rights reserved
 * ************************************************
 */
@Component
public class ThsRequestChargeBO {

    private static final Logger logger = LoggerFactory.getLogger(ThsRequestChargeBO.class);

    @Autowired
    private MemberCarHelperService memberCarHelperService;

    /**
     * 计算费用
     *
     * @param thsChargingRulesPO
     * @param inTime
     * @return
     */
    public Integer getPayableMoney(ThsChargingRulesPO thsChargingRulesPO, String carNo, Date inTime) {
        String chargeDetails = thsChargingRulesPO.getChargeDetails();
        logger.info("计算费用 parkCode -> {} , inTime -> {},chargeDetails -> {}", thsChargingRulesPO.getParkCode(), inTime, chargeDetails);
        if (memberCarHelperService.vaildMember(thsChargingRulesPO.getParkCode(), carNo) != null) {
            return 0;
        }
        ThsRequestChargeAbstract requestChargeAbstract = null;
        switch (thsChargingRulesPO.getChargeType()) {
            //按次收费
            case 0:
                logger.info("计算费用，按次收费 parkCode -> {} , inTime -> {}", thsChargingRulesPO.getParkCode(), inTime);
                return (Integer) JSON.parseObject(chargeDetails).get("oneTimeMoney");
            //按时段收费
            case 1:
                logger.info("计算费用，按时段收费 parkCode -> {} , inTime -> {}", thsChargingRulesPO.getParkCode(), inTime);
                requestChargeAbstract = new ThsTimeFramePayableMoney();
                break;
            //按间隔收费
            case 2:
                logger.info("计算费用，按间隔收费 parkCode -> {} , inTime -> {}", thsChargingRulesPO.getParkCode(), inTime);
                requestChargeAbstract = new ThsIntervalPayableMoney();
                break;
        }
        return requestChargeAbstract.getPayableMoney(thsChargingRulesPO, inTime);
    }

}
